==> p4est_2.2.orig.tar.xz: p4est-2.2/example/steps/hw32.h <==
/*  GIMP header image file format (RGB) */

/** \file hw32.h
 *
 * This file containts the image data used in the step1 example.
 */

#ifdef P4EST_ENABLE_DEBUG
static unsigned int width = 32;
static unsigned int height = 32;
#endif

/*  Call this macro repeatedly.  After each use, the pixel data can be extracted  */

/** Access a pixel of the image and move the data pointer forward. */
#define HW32_HEADER_PIXEL(data,pixel) {\
pixel[0] = (((data[0] - 33) << 2) | ((data[1] - 33) >> 4)); \
pixel[1] = ((((data[1] - 33) & 0xF) << 4) | ((data[2] - 33) >> 2)); \
pixel[2] = ((((data[2] - 33) & 0x3) << 6) | ((data[3] - 33))); \
data += 4; \
}
/** The image data is encoded as a C string. */
static const char *hw32_header_data =
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````!!!!````````!!!!````````````````````````````````````"
	"````````````````!!!!````````````````!!!!````````````````````````"
	"````````````!!!!````````!!!!````````````````````````````````````"
	"````````````````!!!!````````````````!!!!````````````````````````"
	"````````````!!!!````````!!!!````````````````````````````````````"
	"````````````````!!!!````````````````!!!!````````[OLK45V.$1U.,3UN"
	"S=H*````````!!!!````````!!!!````````Y/$A0T]`$!Q-1%\"!Y?(B````````"
	"````````````````!!!!!!!!!!!!!!!!!!!!!!!!````````76F:I+#A_0DYNL;W"
	",CYO````````!!!!````````!!!!````````45V.?8FZ]@(R>X>X5&\"1````````"
	"````````````````!!!!````````````````!!!!````````%R-4!!!!!!!!!!!!"
	"!A)#````````!!!!````````!!!!````````%\"!1\\_`P````\\O\\O%2%2````````"
	"````````````````!!!!````````````````!!!!````````%B)3Z?8F````````"
	"````````````!!!!````````!!!!````````%\"!1\\_`P````\\O\\O%2%2````````"
	"````````````````!!!!````````````````!!!!````````7VN<7VN<[OLKYO,C"
	"76F:````````!!!!````````!!!!````````45V.@(R]]P,S?8FZ5&\"1````````"
	"````````````````!!!!````````````````!!!!````````\\?XN7FJ;%2%2)3%B"
	"KKKK````````!!!!````````!!!!````````Y/$A0T]`#QM,1%\"!Y?(B````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````!!!!````````````````````````!!!!````"
	"````(R]@W.D9````````.T=X````````W>H:(R]@````````````````````````"
	"````````````````````````````!!!!````````````````````````!!!!````"
	"````8FZ?G:G:````X>X>!!!!V>86````HJ[?8V^@````````````````````````"
	"````````````````````````````!!!!````````````````````````!!!!````"
	"````HJ[?7FJ;````HZ_@$1U.E*#1````9W.DHJ[?````Y/$A0T]`$!Q-1%\"!Y?(B"
	"````````!!!!DI[/(\"Q=!1%\"````!!!!````````XN\\?.45V#QM,>X>X!!!!````"
	"````X>X>'RM<````9'\"ABY?(3UN,````*S=HXN\\?````45V.?8FZ]@(R>X>X5&\"1"
	"````````!!!!:'2E[OLK````````!!!!````````45V.@(R]]@(R?8FZ!!!!````"
	"````````(2U>X.T=-T-T_0DY(2U>ZO<G(BY?````````%\"!1\\_`P````\\O\\O%2%2"
	"````````!!!!\\_`P````````````!!!!````````$Q]0\\_`P````\\_`P!!!!````"
	"````````8&R=A9'\"6F:7````6666=X.T86V>````````%\"!1\\_`P````\\O\\O%2%2"
	"````````!!!!````````````````!!!!````````$Q]0\\_`P````\\_`P!!!!````"
	"````````H*S=%2%2HZ_@````HJ[?#AI+H*S=````````45V.@(R]]P,S?8FZ5&\"1"
	"````````!!!!````````````````!!!!````````45V.@(R]]P,S?8FZ!!!!````"
	"````````W^P<!!!!ZO<G````ZO<G!!!!X.T=````````Y/$A0T]`#QM,1%\"!Y?(B"
	"````````!!!!````````````````!!!!````````XN\\?.45V#QM,>X>X!!!!````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"";

==> p4est_2.3.6.orig.tar.xz: p4est-2.3.6/example/steps/hw32.h <==
/*  GIMP header image file format (RGB) */

/** \file hw32.h
 *
 * This file containts the image data used in the step1 example.
 */

#ifdef P4EST_ENABLE_DEBUG
static unsigned int width = 32;
static unsigned int height = 32;
#endif

/*  Call this macro repeatedly.  After each use, the pixel data can be extracted  */

/** Access a pixel of the image and move the data pointer forward. */
#define HW32_HEADER_PIXEL(data,pixel) {\
pixel[0] = (((data[0] - 33) << 2) | ((data[1] - 33) >> 4)); \
pixel[1] = ((((data[1] - 33) & 0xF) << 4) | ((data[2] - 33) >> 2)); \
pixel[2] = ((((data[2] - 33) & 0x3) << 6) | ((data[3] - 33))); \
/* data += 4; */ \
/* We do not move forward due to having split the string */ \
}
/** The image data is encoded as a C string. */
static const char hw32_header_data[4][1028] = {
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````!!!!````````!!!!````````````````````````````````````"
	"````````````````!!!!````````````````!!!!````````````````````````"
	"````````````!!!!````````!!!!````````````````````````````````````"
	"````````````````!!!!````````````````!!!!````````````````````````"
	"````````````!!!!````````!!!!````````````````````````````````````"
        "```" ,
	"````````````````!!!!````````````````!!!!````````[OLK45V.$1U.,3UN"
	"S=H*````````!!!!````````!!!!````````Y/$A0T]`$!Q-1%\"!Y?(B````````"
	"````````````````!!!!!!!!!!!!!!!!!!!!!!!!````````76F:I+#A_0DYNL;W"
	",CYO````````!!!!````````!!!!````````45V.?8FZ]@(R>X>X5&\"1````````"
	"````````````````!!!!````````````````!!!!````````%R-4!!!!!!!!!!!!"
	"!A)#````````!!!!````````!!!!````````%\"!1\\_`P````\\O\\O%2%2````````"
	"````````````````!!!!````````````````!!!!````````%B)3Z?8F````````"
	"````````````!!!!````````!!!!````````%\"!1\\_`P````\\O\\O%2%2````````"
	"````````````````!!!!````````````````!!!!````````7VN<7VN<[OLKYO,C"
	"76F:````````!!!!````````!!!!````````45V.@(R]]P,S?8FZ5&\"1````````"
	"````````````````!!!!````````````````!!!!````````\\?XN7FJ;%2%2)3%B"
	"KKKK````````!!!!````````!!!!````````Y/$A0T]`#QM,1%\"!Y?(B````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
        "```" ,
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````!!!!````````````````````````!!!!````"
	"````(R]@W.D9````````.T=X````````W>H:(R]@````````````````````````"
	"````````````````````````````!!!!````````````````````````!!!!````"
	"````8FZ?G:G:````X>X>!!!!V>86````HJ[?8V^@````````````````````````"
	"````````````````````````````!!!!````````````````````````!!!!````"
	"````HJ[?7FJ;````HZ_@$1U.E*#1````9W.DHJ[?````Y/$A0T]`$!Q-1%\"!Y?(B"
	"````````!!!!DI[/(\"Q=!1%\"````!!!!````````XN\\?.45V#QM,>X>X!!!!````"
	"````X>X>'RM<````9'\"ABY?(3UN,````*S=HXN\\?````45V.?8FZ]@(R>X>X5&\"1"
	"````````!!!!:'2E[OLK````````!!!!````````45V.@(R]]@(R?8FZ!!!!````"
	"````````(2U>X.T=-T-T_0DY(2U>ZO<G(BY?````````%\"!1\\_`P````\\O\\O%2%2"
	"````````!!!!\\_`P````````````!!!!````````$Q]0\\_`P````\\_`P!!!!````"
        "```" ,
	"````````8&R=A9'\"6F:7````6666=X.T86V>````````%\"!1\\_`P````\\O\\O%2%2"
	"````````!!!!````````````````!!!!````````$Q]0\\_`P````\\_`P!!!!````"
	"````````H*S=%2%2HZ_@````HJ[?#AI+H*S=````````45V.@(R]]P,S?8FZ5&\"1"
	"````````!!!!````````````````!!!!````````45V.@(R]]P,S?8FZ!!!!````"
	"````````W^P<!!!!ZO<G````ZO<G!!!!X.T=````````Y/$A0T]`#QM,1%\"!Y?(B"
	"````````!!!!````````````````!!!!````````XN\\?.45V#QM,>X>X!!!!````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
	"````````````````````````````````````````````````````````````````"
        "\0\0\0" };
